--[[ Labelling Module]]

function intialiselabel()
	for i=1,#Bar do
		if Bar[i].Data.label~=nil then Bar[i]:Label() end
	end
end

function NewBar:Label()
	if self.Data.label==nil then return end
	
	--Defaults
	if self.Data.label.Font==nil then self.Data.label.Font="Verdana12" end
	if self.Data.label.x==nil then self.Data.label.x=0 end
	if self.Data.label.y==nil then self.Data.label.y=0 end
	
	local x=self.Data.label.x
	local y=self.Data.label.y
		
	if self.Data.label.xsize==nil then self.Data.label.xsize=self:GetWidth() end
	if self.Data.label.ysize==nil then self.Data.label.ysize=self:GetHeight() end
	
	if self.Data.label.color==nil then
		self.Data.label.color={}
		self.Data.label.color[1]=0
		self.Data.label.color[2]=0
		self.Data.label.color[3]=0
		self.Data.label.color[4]=0
	end
	
	if self.Data.label.fcolor==nil then
		self.Data.label.fcolor={}
		self.Data.label.fcolor[1]=1
		self.Data.label.fcolor[2]=1
		self.Data.label.fcolor[3]=1
		self.Data.label.fcolor[4]=1
	end
	
	local name=self.Data.name or "?"
	
	if self.Data.label.Alignment==nil then self.Data.label.Alignment="TopLeft" end
	
	if self.labelControl~=nil then	self.labelControl:SetVisible(false) self.labelControl=nil end
	self.labelControl=Turbine.UI.Label()
	
		self.labelControl:SetParent(self.Window)
		
		self.labelControl:SetSize(self.Data.label.xsize,self.Data.label.ysize)
		self.labelControl:SetFont(Turbine.UI.Lotro.Font[self.Data.label.Font])
		self.labelControl:SetStretchMode(1)
		self.labelControl:SetMouseVisible(false)
		self.labelControl:SetVisible(true)
		self.labelControl:SetOpacity(self:GetOpacity())
		self.labelControl:SetPosition(x,y)
		self.labelControl:SetText(name)
		self.labelControl:SetFontStyle( Turbine.UI.FontStyle.Outline );
		self.labelControl:SetOutlineColor( Turbine.UI.Color( 0, 0, 0 ) );
		self.labelControl:SetTextAlignment( Turbine.UI.ContentAlignment[self.Data.label.Alignment] )
		self.labelControl:SetZOrder(9999)	
		self.labelControl:SetBackColor(Turbine.UI.Color(self.Data.label.color[1],self.Data.label.color[2],self.Data.label.color[3],self.Data.label.color[4]))
		self.labelControl:SetForeColor(Turbine.UI.Color(self.Data.label.fcolor[1],self.Data.label.fcolor[2],self.Data.label.fcolor[3],self.Data.label.fcolor[4]))
		
end

--Add the "label Bar" option to every Bar.
table.insert(Context,
function (self,contextMenu,contextMenuItems)

	local LabelBar= Turbine.UI.MenuItem( "Label;");
	contextMenu.Label = LabelBar:GetItems()
	
	local val=(self.Data.label~=nil)
	local LabelBarMenu={}

	LabelBarMenu[1]=Turbine.UI.MenuItem("Show Label",true,val)
	LabelBarMenu[1].Click=function() 
		if self.Data.label~=nil then
			self.Data.label=nil
			self.labelControl:SetVisible(false)
			self.labelControl=nil
		else
			self.Data.label={}
			self.Data.label.x=0
			self.Data.label.y=0
			self:Label()
		end
	end
	contextMenu.Label:Add(LabelBarMenu[1])
	
	--Only show if this bar has a label
	if val then 
		--Movement

		LabelBarMenu[2]=Turbine.UI.MenuItem("Move, Size & Colour Label",true)
		LabelBarMenu[2].Click=function() 
			Opt.Update(self)
		end
		contextMenu.Label:Add(LabelBarMenu[2])
		
		--Font
		LabelBarMenu[3] = Turbine.UI.MenuItem("Select label font;")
			contextMenu.SubMenuItems = LabelBarMenu[3]:GetItems()
			local suboption5={}
			local font={}
			j=1
			for i in pairs(Turbine.UI.Lotro.Font) do 
				font[j]=i
				j=j+1
			end
			table.sort(font, function (a,b)	
					return (a < b) 
			 end)
			 for i=1,#font do
				suboption5[i] = Turbine.UI.MenuItem(font[i],true,font[i]==self.Data.label.Font)
					suboption5[i].Click = function () 
						self.Data.label.Font=font[i]
						self:Label()
					end

				contextMenu.SubMenuItems:Add(suboption5[i])
			end
		contextMenu.Label:Add(LabelBarMenu[3])	
		
		--Alignment
		LabelBarMenu[4] = Turbine.UI.MenuItem("Select label alignment;")
			contextMenu.SubMenuItems = LabelBarMenu[4]:GetItems()
			local alignoption={}
			local align={}
			j=1
			for i in pairs(Turbine.UI.ContentAlignment) do 
				align[j]=i
				j=j+1
			end
			table.sort(align, function (a,b)	
					return (a < b) 
			 end)
			 for i=1,#align do
				alignoption[i] = Turbine.UI.MenuItem(align[i],true,align[i]==self.Data.label.Alignment)
					alignoption[i].Click = function () 
						self.Data.label.Alignment=align[i]
						self:Label()
					end

				contextMenu.SubMenuItems:Add(alignoption[i])
			end

		contextMenu.Label:Add(LabelBarMenu[4])	
	end
			
	contextMenuItems:Add( LabelBar )
end)

intialiselabel()


--LabelPositionOptions box
--************************

table.insert(Opt.Module,
	function()

	Opt.LabelBox=CollapseBox("Label Options","f",2,true)
	
	Opt.ListBox:AddItem(Opt.LabelBox)
	
	Opt.label=Opt.CheckBox("Label Shown?", function (k,i)
		if k then
			Bar[i].Data.label={}
			Bar[i].Data.label.x=0
			Bar[i].Data.label.y=0
			Bar[i]:Label()
		else
			if Bar[i].Data.label~=nil then
				Bar[i].Data.label=nil
				Bar[i].labelControl:SetVisible(false)
				Bar[i].labelControl=nil
			end
		end
	end)
	Opt.LabelBox.Content:AddItem(Opt.label)
	table.insert(Opt.source,"label")
	
	Opt.table.label=true
	
	Opt.LabelBox.Content:AddItem(optionlabel(320,"",true))
	Opt.LabelBox.Content:AddItem(optionlabel(320,"Position:",true))
	Opt.LabelBox.Content:AddItem(optionlabel(320,"Size:",true))
	
	Opt.LS={} --Label Sliders
	--NOTE: Values for these are set in NewOption.lua
	
	Opt.LS.x=Opt.Slider("x Pos",-200,200,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.x=k Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.x)
	Opt.LS.xs=Opt.Slider("Width",5,500,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.xsize=k Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.xs)
	
	Opt.LS.y=Opt.Slider("y Pos",-200,200,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.y=k Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.y)
	Opt.LS.ys=Opt.Slider("Height",5,500,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.ysize=k Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.ys)
	
	Opt.LabelBox.Content:AddItem(optionlabel(320,"Back Colour:",true))
	Opt.LabelBox.Content:AddItem(optionlabel(320,"Fore Colour:",true))
	
	Opt.LS.BO=Opt.Slider("Opacity",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.color[1]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.BO)

	Opt.LS.FO=Opt.Slider("Opacity",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.fcolor[1]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.FO)
	
	Opt.LS.BR=Opt.Slider("Red",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.color[2]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.BR)
	Opt.LS.FR=Opt.Slider("Red",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.fcolor[2]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.FR)
	
	Opt.LS.BG=Opt.Slider("Green",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.color[3]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.BG)
	Opt.LS.FG=Opt.Slider("Green",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.fcolor[3]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.FG)
	
	Opt.LS.BB=Opt.Slider("Blue",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.color[4]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.BB)
	Opt.LS.FB=Opt.Slider("Blue",0,100,function(k,i) if Bar[i].Data.label~=nil then Bar[i].Data.label.fcolor[4]=k/100 Bar[i]:Label() end end) 
	Opt.LabelBox.Content:AddItem(Opt.LS.FB)
	
	-- Look at line 335 of NewOption.Lua

	Opt.LabelFont=Opt.DropDown(
		font,
		function(k,i)
			if Bar[i].Data.label~=nil then
				Bar[i].Data.label.Font=font[k+1]
				Bar[i]:Label()
			end
		end,
		"Font:")
	Opt.LabelBox.Content:AddItem(Opt.LabelFont)	
		 
	Opt.LabelAlignment=Opt.DropDown(
		align,
		function(k,i)
			if Bar[i].Data.label~=nil then
				Bar[i].Data.label.Alignment=align[k+1]
				Bar[i]:Label()
			end
		end,
		"Align:")
	Opt.LabelBox.Content:AddItem(Opt.LabelAlignment)

	end)
	
table.insert(Opt.Updaters, 
	function()
	if Opt.LS.x~=nil then
		--Set back colours to nil - can change again later.
		Opt.LS.x:SetBackColor(nil)
		Opt.LS.y:SetBackColor(nil)
		Opt.LS.xs:SetBackColor(nil)
		Opt.LS.ys:SetBackColor(nil)
		Opt.LS.BO:SetBackColor(nil)
		Opt.LS.FO:SetBackColor(nil)
		Opt.LS.BR:SetBackColor(nil)
		Opt.LS.FR:SetBackColor(nil)
		Opt.LS.BG:SetBackColor(nil)
		Opt.LS.FG:SetBackColor(nil)
		Opt.LS.BB:SetBackColor(nil)
		Opt.LS.FB:SetBackColor(nil)
		Opt.LabelFont:SetBackColor(nil)
		Opt.LabelAlignment:SetBackColor(nil)
	
		if Opt.tab.label~=nil then
			if Opt.tab.label.color~=nil then
				Opt.LS.x:SetVal(Opt.tab.label.x)
				Opt.LS.y:SetVal(Opt.tab.label.y)
				Opt.LS.xs:SetVal(Opt.tab.label.xsize)
				Opt.LS.ys:SetVal(Opt.tab.label.ysize)
				Opt.LS.BO:SetVal(Opt.tab.label.color[1]*100)
				Opt.LS.FO:SetVal(Opt.tab.label.fcolor[1]*100)
				Opt.LS.BR:SetVal(Opt.tab.label.color[2]*100)
				Opt.LS.FR:SetVal(Opt.tab.label.fcolor[2]*100)
				Opt.LS.BG:SetVal(Opt.tab.label.color[3]*100)
				Opt.LS.FG:SetVal(Opt.tab.label.fcolor[3]*100)
				Opt.LS.BB:SetVal(Opt.tab.label.color[4]*100)
				Opt.LS.FB:SetVal(Opt.tab.label.fcolor[4]*100)
				Opt.LabelFont:SetVal(Opt.tab.label.Font)
				Opt.LabelAlignment:SetVal(Opt.tab.label.Alignment)
			end
		end
		
		if Opt.Check.label==nil then Opt.check.label={} end
		if Opt.Check.label.color==nil then Opt.Check.label.color={} end
		if Opt.Check.label.fcolor==nil then Opt.Check.label.fcolor={} end
		
		--Highlight non-equal controls
		if Opt.Check.label.x then 				Opt.LS.x:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.y then 				Opt.LS.y:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.xsize then 			Opt.LS.xs:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.ysize then 			Opt.LS.ys:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.color[1] then 		Opt.LS.BO:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.fcolor[1] then 		Opt.LS.FO:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.color[2] then 		Opt.LS.BR:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.fcolor[2] then 		Opt.LS.FR:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.color[3] then 		Opt.LS.BG:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.fcolor[3] then 		Opt.LS.FG:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.color[4] then 		Opt.LS.BB:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.fcolor[4] then 		Opt.LS.FB:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.LabelFont then 		Opt.LabelFont:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
		if Opt.Check.label.LabelAlignment then 	Opt.LabelAlignment:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3)) end
			
	end
end)
	
	
	